@@ -27,4 +27,10 @@ class DeleteLogConfigRequest(RpcRequest):
 		return self.get_query_params().get('LogType')
 
 	def set_LogType(self,LogType):
-		self.add_query_param('LogType',LogType)
\ No newline at end of file
+		self.add_query_param('LogType',LogType)
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
